@@ -17,11 +17,20 @@ App::RetroPAN - Makes a historic minicpan ⏳
 
   my ($author, $dist_name, $url) = find_module_on_date("2011-01-01T00:00:00", "Moose");
 
+  my @dependencies = find_deps_on_date_with_perl("2011-01-01T00:00:00", $], "Moose", "Mouse", "Moo", ...);
+
+  my @dependencies = find_modules_dependencies($author, $dist_name, $]);
+
 =head1 DESCRIPTION
 
 Uses the MetaCPAN API to find releases made prior to a given date to
 satisfy your modules' dependencies.
 
+=head2 Core modules
+
+Newer versions of modules existing in core are currently ignored. This may be
+desirable as users may be reluctant to upgrade core modules from CPAN.
+
 =head1 SEE ALSO
 
 =over
@@ -48,19 +57,21 @@ Dave Lambley <dlambley@cpan.org>
 
 use HTTP::Request;
 use LWP::UserAgent;
-use List::Util qw/ uniq /;
+use List::MoreUtils qw/ uniq /;
 use Module::CoreList;
 use OrePAN2::Injector;
 use OrePAN2::Indexer;
 
 use Cpanel::JSON::XS qw/ encode_json decode_json /;
 
-our $VERSION = '0.01_05';
+our $VERSION = '0.03_01';
 
 my $ua = LWP::UserAgent->new( keep_alive => 2, agent => "retropan/$VERSION" );
 
 sub find_module_dependencies {
-    my ($au, $dist) = @_;
+    my ($au, $dist, $perl_version) = @_;
+
+    $perl_version ||= $];
 
     my $q = {
         "size" => 1,
@@ -98,16 +109,18 @@ sub find_module_dependencies {
     }
 
     my @deps =
-        grep { !Module::CoreList::is_core($_) }
+        grep { !Module::CoreList::is_core($_, undef, $perl_version) }
         grep { $_ ne "perl" }
         map { $_->{module} } @{ $hit->{_source}->{dependency} };
 
     return @deps;
 }
-sub find_module_on_date {
-    my ($module, $before) = @_;
 
-    return if Module::CoreList::is_core($module);
+sub find_module_on_date {
+    my ($module, $before, $perl_version) = @_;
+
+    $perl_version ||= $];
+    return if Module::CoreList::is_core($module, undef, $perl_version);
 
     # We prefer authorized modules, but can fall back to unauthorized if none
     # available.
@@ -183,6 +196,11 @@ sub find_module_on_date {
 
 sub find_deps_on_date {
     my ($before, @modules) = @_;
+    return find_deps_on_date_with_perl($before, $], @modules);
+}
+
+sub find_deps_on_date_with_perl {
+    my ($before, $perl_version, @modules) = @_;
 
     my %done_modules;
     my @dists_required;
@@ -192,12 +210,12 @@ sub find_deps_on_date {
         my $mod = pop @modules;
         next if $done_modules{$mod};
 
-        my ($au, $dist, $url) = find_module_on_date($mod, $before);
+        my ($au, $dist, $url) = find_module_on_date($mod, $before, $perl_version);
         $done_modules{$mod} = 1;
         next if !defined($au) || !defined($dist);
         $dist_to_url{"$au/$dist"} = $url;
 
-        push @modules, find_module_dependencies($au, $dist);
+        push @modules, find_module_dependencies($au, $dist, $perl_version);
         unshift @dists_required, "$au/$dist";
     }
 
